/* version.h
 *
 * $Id: version.h,v 1.8 2000/02/22 21:50:55 nisse Exp $ */

/* lsh, an implementation of the ssh protocol
 *
 * Copyright (C) 1998 Niels Mller
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef LSH_VERSION_H_INCLUDED
#define LSH_VERSION_H_INCLUDED

#include "lsh_types.h"

#define CLIENT_PROTOCOL_VERSION "2.0"
#define SERVER_PROTOCOL_VERSION "2.0"

#if WITH_SSH1_FALLBACK
#define SSH1_SERVER_PROTOCOL_VERSION "1.99"
#endif

#define SOFTWARE_CLIENT_VERSION ("lsh_" VERSION)
#define SOFTWARE_SERVER_VERSION ("lshd_" VERSION)

/* Use "psst@net.lut.ac.uk" ? */
#define BUG_ADDRESS "<bug-lsh@gnu.org>"

#endif /* LSH_VERSION_H_INCLUDED */
